pub struct Point {
pub id: PointId,
pub version: u64,
pub vector: Vector,
pub multivector: Option<MultiVector>,
pub sparse_vectors: HashMap<String, SparseVector>,
pub payload: Option<Value>,
}Expand description
A point in the vector space with optional payload
Fields
id: PointIdversion: u64Version number - incremented on each update
vector: VectorVector data - backwards compatible field name
multivector: Option<MultiVector>Optional multivector data for ColBERT-style search
sparse_vectors: HashMap<String, SparseVector>Named sparse vectors (e.g., {“keywords”: SparseVector})
payload: Option<Value>Implementations
Sourceimpl Point
impl Point
Sourcepub fn new(id: PointId, vector: Vector, payload: Option<Value>) -> Point
pub fn new(id: PointId, vector: Vector, payload: Option<Value>) -> Point
Create a new point with a single dense vector
Sourcepub fn new_multi(
id: PointId,
multivector: MultiVector,
payload: Option<Value>,
) -> Point
pub fn new_multi( id: PointId, multivector: MultiVector, payload: Option<Value>, ) -> Point
Create a new point with a multivector (ColBERT-style)
Sourcepub fn new_sparse(
id: PointId,
sparse_vectors: HashMap<String, SparseVector>,
payload: Option<Value>,
) -> Point
pub fn new_sparse( id: PointId, sparse_vectors: HashMap<String, SparseVector>, payload: Option<Value>, ) -> Point
Create a new point with sparse vectors
Sourcepub fn add_sparse_vector(&mut self, name: String, sparse: SparseVector)
pub fn add_sparse_vector(&mut self, name: String, sparse: SparseVector)
Add a sparse vector to this point
Sourcepub fn get_sparse_vector(&self, name: &str) -> Option<&SparseVector>
pub fn get_sparse_vector(&self, name: &str) -> Option<&SparseVector>
Get a sparse vector by name
Sourcepub fn has_multivector(&self) -> bool
pub fn has_multivector(&self) -> bool
Check if this point has multivector data
Sourcepub fn get_multivector(&self) -> Option<&MultiVector>
pub fn get_multivector(&self) -> Option<&MultiVector>
Get the multivector if present
pub fn with_payload(self, payload: Value) -> Point
pub fn with_multivector(self, multivector: MultiVector) -> Point